@@ -5,12 +5,41 @@
 # --------------------------------------------------------------------------
 
 
+from enum import Enum
 from typing import List, Optional, Union
 from pydantic import BaseModel
 from .literals import STATUS_STATE
 from .step import SwitchGuideStep, SwitchGuideStepComponent, SwitchGuideStepDefinitionUiAssets, SwitchGuideStepDependency, SwitchGuideStepOverrides
 
 
+
+class SwitchGuideScope(Enum):
+    """Scope of the Guide"""
+
+    PORTFOLIO = 'Portfolio'
+    """Single guide instance for the entire Portfolio"""
+
+    SITE = 'Site'
+    """Single guide instance per Site in the Portfolio"""
+
+
+class MarketplaceUserType(Enum):
+    """User type for the Marketplace"""
+
+    NONE = 'None'
+    """Not available on the Marketplace
+    Will be hidden from the marketplace if the guide was previously available.
+    """
+
+    ALL = 'All'
+    """Available for all users"""
+
+    SWITCHUSERONLY = 'SwitchUserOnly'
+    """Available for Switch Users only
+    Useful for testing a Guide before the guide is made available for all users in the Marketplace.
+    """
+
+
 class SwitchGuideStatus(BaseModel):
     state: STATUS_STATE
     percentageCompleted: int = 0
@@ -26,6 +55,9 @@ class SwitchGuideDefinitionOptions(BaseModel):
     Such as logs associated with each individual step.
     """
 
+    availableOnMarketplaceForUserType: Optional[MarketplaceUserType] = MarketplaceUserType.ALL,
+    """User types the guide is available for on the Marketplace"""
+
 
 class SwitchGuideSummaryStepEvents(BaseModel):
     """Events that can be triggered on the Summary Step
@@ -64,6 +96,18 @@ class SwitchGuideDefinition(BaseModel):
     instructions: str
     """Instructions on how to use the Guide"""
 
+    imageUrl: Optional[str] = None
+    """Image URL for the Guide
+    This image will be displayed on the Marketplace.
+    Relative to Switch Assets CDN example: static/hub-assets/example/location/of/image.png
+    """
+
+    tags: Optional[List[str]] = []
+    """Tags associated with the Guide"""
+
+    scope: Optional[SwitchGuideScope] = SwitchGuideScope.PORTFOLIO
+    """Scope of the Guide"""
+
     summaryStep: Optional[SwitchGuideSummaryStepConfigDefinition]
     """Configuration for the Summary Step"""
     
