@@ -7,7 +7,6 @@
 
 from abc import abstractmethod
 from io import StringIO
-import json
 import logging
 import sys
 import pandas
@@ -86,6 +85,15 @@ class GuideStepDefinitionTask(Task):
 
     @abstractmethod
     def process(self, api_inputs: ApiInputs, journey_input: SwitchGuideStepProcessInput) -> SwitchGuideStepApiResponse:
+        """ This method requires user wait for completion. 
+        How long this method should run depends on how long a user is willing to wait on the page. 
+        Use GuideStepDefinitionAsyncTask if you want to run this method in background.
+
+        This method will be called by the Guides Backend under two conditions.
+            1. When user completes the requirements of a component associated with this step.
+        
+        Add your logic here to extract, process, and export data how ever you see fit.
+        """
         return None
     
     def update_component(self, response: SwitchGuideStepApiResponse, component: SwitchGuideStepComponent):
@@ -115,7 +123,9 @@ class GuideStepDefinitionTask(Task):
             self.logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
-        register = sw.pipeline.Automation.register_task(api_inputs, self)
+        script_response = sw.pipeline.Automation.register_task(api_inputs, self)
+
+        _, register = (0, script_response) if type(script_response) is pandas.DataFrame else script_response
 
         self.logger.info(register)
 
@@ -145,9 +155,9 @@ class GuideStepDefinitionTask(Task):
             self.logger.error(
                 'No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
-        
-        response_json_data = json.loads(response.text)
-        response_data = pandas.read_json(StringIO(json.dumps(response_json_data['journeyStepDefinition'])), typ='Series').to_frame().T
+
+        response_data = pandas.read_json(StringIO(response.text), typ='Series').to_frame().T
+        response_data.rename(columns = {'driverId':'guideStepDefinitionId'}, inplace = True)
         response_data.columns = _column_name_cap(response_data.columns)
 
         return response_status, response_data
\ No newline at end of file
