@@ -13,5 +13,6 @@ functions for retrieving details of existing tasks on the Switch Automation Plat
 from .GuideDefinitionTask import GuideDefinitionTask
 from .GuideRetrySupportTask import GuideRetrySupportTask
 from .GuideStepDefinitionTask import GuideStepDefinitionTask
+from .GuideStepDefinitionBackgroundTask import GuideStepDefinitionBackgroundTask
 
-__all__ = ['GuideDefinitionTask', 'GuideRetrySupportTask', 'GuideStepDefinitionTask']
+__all__ = ['GuideDefinitionTask', 'GuideRetrySupportTask', 'GuideStepDefinitionTask', 'GuideStepDefinitionBackgroundTask']
